<?php

namespace Drupal\Tests\media_migration\Functional;

/**
 * Tests the transformation of embed image media tokens to media_embed.
 *
 * @group media_migration
 *
 * @group legacy
 */
class MigrateEmbedMediaTokenToMediaEmbedTest extends MigrateEmbedMediaTokenTestBase {

  /**
   * {@inheritdoc}
   */
  protected $embedTokenDestinationFilterPlugin = 'media_embed';

  /**
   * {@inheritdoc}
   */
  protected $embedMediaCssSelector = '.field--name-body.field--type-text-with-summary .media.media--type-image .field--name-field-media-image';

  /**
   * Tests the result of Media Migration's embed media token transform.
   *
   * @param string $reference_method
   *   The method of how embed media is referenced.
   * @param array $extra_modules
   *   Additional modules to enable before the migration.
   *
   * @dataProvider providerMediaEmbedTransform
   */
  public function testMediaTokenToMediaEmbedTransform(string $reference_method, array $extra_modules) {
    // The media embed filter exists only from Drupal 8.8+.
    if (version_compare(\Drupal::VERSION, '8.8', '<')) {
      $this->pass('The media embed filter exists only from Drupal 8.8+.');
      return;
    }

    // Set the reference method.
    $this->setEmbedMediaReferenceMethod($reference_method);

    if (!empty($extra_modules)) {
      $this->container->get('module_installer')->install($extra_modules);
    }

    $this->assertMigrateUpgradeViaUi();
    $this->assertMediaMigrationResults();
    $expected_node1_embed_attributes = [
      0 => [
        'data-view-mode' => 'wysiwyg',
        'data-entity-type' => 'media',
        'data-entity-uuid' => TRUE,
        'alt' => 'Different alternative text about blue.png in the test article',
        'title' => 'Different title copy for blue.png in the test article',
        'data-align' => 'center',
      ],
    ];
    $this->assertMediaTokenTransform($expected_node1_embed_attributes);
    $this->assertNode1FieldValues($expected_node1_embed_attributes);
  }

  /**
   * Data provider for ::testMediaTokenToMediaEmbedTransform().
   *
   * @return array
   *   The test cases.
   */
  public function providerMediaEmbedTransform() {
    return [
      // ID reference method. This should be neutral for media_embed token
      // transform destination.
      'ID reference method, no additional modules' => [
        'reference method' => 'id',
        'additional modules' => [],
      ],
      'ID reference method, Entity Embed installed' => [
        'reference method' => 'id',
        'additional modules' => ['entity_embed'],
      ],
      // UUID reference method.
      'UUID reference method, no additional modules' => [
        'reference method' => 'uuid',
        'additional modules' => [],
      ],
      'UUID reference method, Entity Embed installed' => [
        'reference method' => 'uuid',
        'additional modules' => ['entity_embed'],
      ],
    ];
  }

}
