<?php

namespace Drupal\Tests\media_migration\Kernel\Migrate;

/**
 * Tests media migration from non-media source.
 *
 * @group media_migration
 */
class MediaMigrationPlainTest extends MediaMigrationTestBase {

  /**
   * {@inheritdoc}
   */
  protected function getFixtureFilePath() {
    return drupal_get_path('module', 'media_migration') . '/tests/fixtures/drupal7_nomedia.php';
  }

  /**
   * Tests the migration of plain file and image fields to media reference.
   *
   * @dataProvider providerTestFieldTypeMigration
   */
  public function testFieldTypeMigration(bool $classic_node_migration) {
    $this->setClassicNodeMigration($classic_node_migration);

    // The Drupal 8|9 entity revision migration causes a file not found
    // exception without properly migrated files. For this test, it is enough to
    // properly migrate the public files.
    $fs_fixture_path = implode(DIRECTORY_SEPARATOR, [
      DRUPAL_ROOT,
      drupal_get_path('module', 'media_migration'),
      'tests',
      'fixtures',
    ]);
    $file_migration = $this->getMigration('d7_file');
    $source = $file_migration->getSourceConfiguration();
    $source['constants']['source_base_path'] = $fs_fixture_path;
    $file_migration->set('source', $source);

    $this->executeMigration($file_migration);
    $this->executeMigrations([
      'd7_view_modes',
      'd7_field',
      'd7_node_type',
      'd7_field_instance',
    ]);
    // Abusing ::startCollectingMessages(): "d7_field_formatter_settings"
    // triggers PluginNotFoundException: The "file_rendered" plugin does not
    // exist.
    $this->startCollectingMessages();
    $this->executeMigrations([
      'd7_field_formatter_settings',
    ]);
    $this->stopCollectingMessages();
    $this->executeMigrations([
      'd7_field_instance_widget_settings',
      'd7_embed_button_media',
      'd7_filter_format',
      // Nodes and media entities need an owner.
      'd7_user_role',
      'd7_user',
      $classic_node_migration ? 'd7_node' : 'd7_node_complete',
    ]);

    // Check configurations.
    $this->assertMediaFieldsAllowedTypes('node', 'article', 'field_image', ['image']);
    $this->assertMediaFieldsAllowedTypes('node', 'article', 'field_image_multi', ['image']);
    $this->assertMediaFieldsAllowedTypes('node', 'article', 'field_file', [
      'audio',
      'document',
      'image',
      'remote_video',
      'video',
    ]);
    $this->assertMediaFieldsAllowedTypes('node', 'article', 'field_file_multi', [
      'audio',
      'document',
      'image',
      'remote_video',
      'video',
    ]);
  }

  /**
   * Data provider for ::testMediaTokenToMediaEmbedTransform().
   *
   * @return array
   *   The test cases.
   */
  public function providerTestFieldTypeMigration() {
    $test_cases = [
      'Classic node migration' => [
        'Classic node migration' => TRUE,
      ],
      'Complete node migration' => [
        'Classic node migration' => FALSE,
      ],
    ];

    // Drupal 8.8.x only has 'classic' node migrations.
    // @see https://www.drupal.org/node/3105503
    if (version_compare(\Drupal::VERSION, '8.9', '<')) {
      $test_cases = array_filter($test_cases, function ($test_case) {
        return $test_case['Classic node migration'];
      });
    }

    return $test_cases;
  }

}
