<?php

namespace Drupal\Tests\media_migration\Kernel\Migrate;

use Drupal\Core\Site\Settings;
use Drupal\media_migration\MediaMigration;
use Drupal\Tests\media_migration\Traits\MediaMigrationAssertionsTrait;
use Drupal\Tests\media_migration\Traits\MediaMigrationTestTrait;
use Drupal\Tests\migrate_drupal\Kernel\MigrateDrupalTestBase;

/**
 * Base class for Media Migration kernel tests.
 */
abstract class MediaMigrationTestBase extends MigrateDrupalTestBase {

  use MediaMigrationTestTrait;
  use MediaMigrationAssertionsTrait;

  /**
   * {@inheritdoc}
   */
  protected $profile = 'standard';

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'comment',
    'datetime',
    'datetime_range',
    'editor',
    'embed',
    'entity_embed',
    'field',
    'file',
    'filter',
    'image',
    'link',
    'media',
    'media_migration',
    'menu_ui',
    'migrate',
    'migrate_drupal',
    'migrate_plus',
    'migrate_tools',
    'node',
    'options',
    'system',
    'taxonomy',
    'telephone',
    'text',
    'user',
  ];

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();
    $this->loadFixture($this->getFixtureFilePath());

    $this->installEntitySchema('file');
    $this->installSchema('file', 'file_usage');
    $this->installEntitySchema('node');
    $this->installSchema('node', 'node_access');
    $this->installEntitySchema('embed_button');
    $this->installEntitySchema('media');
    $this->installEntitySchema('comment');
    $this->installSchema('comment', 'comment_entity_statistics');
    $this->installSchema('media_migration', MediaMigration::MEDIA_UUID_PROPHECY_TABLE);

    $this->createStandardMediaTypes();
  }

  /**
   * Changes the entity embed token transform destination filter plugin.
   *
   * @param string $new_filter_plugin_id
   *   The new token transform destination plugin ID.
   */
  protected function setEmbedTokenDestinationFilterPlugin($new_filter_plugin_id) {
    $current_filter_plugin_id = MediaMigration::getEmbedTokenDestinationFilterPlugin();

    if ($new_filter_plugin_id !== $current_filter_plugin_id) {
      $this->setSetting(MediaMigration::MEDIA_TOKEN_DESTINATION_FILTER_SETTINGS, $new_filter_plugin_id);
    }
  }

  /**
   * Sets the method of the embed media reference.
   *
   * @param string $new_reference_method
   *   The reference method to set. This can be 'id', or 'uuid'.
   */
  protected function setEmbedMediaReferenceMethod($new_reference_method) {
    $current_method = Settings::get(MediaMigration::MEDIA_REFERENCE_METHOD_SETTINGS);

    if ($current_method !== $new_reference_method) {
      $this->setSetting(MediaMigration::MEDIA_REFERENCE_METHOD_SETTINGS, $new_reference_method);
    }
  }

  /**
   * Sets the type of the node migration.
   *
   * @param bool $classic_node_migration
   *   Whether nodes should be migrated with the 'classic' way. If this is
   *   FALSE, and the current Drupal instance has the 'complete' migration, then
   *   the complete node migration will be used.
   */
  protected function setClassicNodeMigration(bool $classic_node_migration) {
    $current_method = Settings::get('migrate_node_migrate_type_classic', FALSE);

    if ($current_method !== $classic_node_migration) {
      $this->setSetting('migrate_node_migrate_type_classic', $classic_node_migration);
    }
  }

}
