<?php

namespace Drupal\Tests\media_migration\Kernel\Plugin\migrate\source\d7;

use Drupal\Tests\media_migration\Traits\MediaMigrationSourceDatabaseTrait;
use Drupal\Tests\media_migration\Traits\MediaMigrationTestTrait;
use Drupal\Tests\migrate\Kernel\MigrateSqlSourceTestBase;

/**
 * Tests the d7_media_source_field_instance_config migration source plugin.
 *
 * @covers \Drupal\media_migration\Plugin\migrate\source\d7\MediaSourceFieldInstance
 * @group media_migration
 */
class MediaSourceFieldInstanceTest extends MigrateSqlSourceTestBase {

  use MediaMigrationTestTrait;
  use MediaMigrationSourceDatabaseTrait;

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'field',
    'file',
    'image',
    'media',
    'media_migration',
    'migrate_drupal',
  ];

  /**
   * {@inheritdoc}
   *
   * @dataProvider providerSource
   *
   * @requires extension pdo_sqlite
   */
  public function testSource(array $source_data, array $expected_data, $expected_count = NULL, array $configuration = [], $high_water = NULL) {
    $this->createStandardMediaTypes();
    parent::testSource($source_data, $expected_data, $expected_count, $configuration, $high_water);
  }

  /**
   * {@inheritdoc}
   */
  public function providerSource() {
    $expected_audio_row = [
      'field_name' => 'field_media_audio_file',
      'type' => 'audio',
      'scheme' => 'public',
      'file_extensions' => 'mp3 wav aac m4a',
    ];
    $expected_document_row = [
      'field_name' => 'field_media_document',
      'type' => 'document',
      'scheme' => 'public',
      'file_extensions' => 'txt doc docx pdf odt',
    ];
    $expected_local_video_row = [
      'field_name' => 'field_media_video_file',
      'type' => 'video',
      'scheme' => 'public',
      'file_extensions' => 'mp4 webm',
    ];
    $expected_image_row_with_default_alt_title_conf = [
      'field_name' => 'field_media_image',
      'type' => 'image',
      'scheme' => 'public',
      'file_extensions' => 'png gif jpg jpeg webp',
      'alt_field' => TRUE,
      'title_field' => FALSE,
      'alt_field_required' => FALSE,
      'title_field_required' => FALSE,
    ];

    return [
      'Audio' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(FALSE),
        ],
        'expected_data' => [$expected_audio_row],
        'count' => 1,
        'plugin_configuration' => [
          'type' => 'audio',
        ],
      ],
      'Document' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(FALSE),
        ],
        'expected_data' => [$expected_document_row],
        'count' => 1,
        'plugin_configuration' => [
          'type' => 'document',
        ],
      ],
      'Local video' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(FALSE),
        ],
        'expected_data' => [$expected_local_video_row],
        'count' => 1,
        'plugin_configuration' => [
          'type' => 'video',
          'scheme' => 'public',
        ],
      ],
      'All: plugin with default configuration' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(FALSE),
        ],
        'expected_data' => [
          $expected_image_row_with_default_alt_title_conf,
          $expected_document_row,
          $expected_local_video_row,
          $expected_audio_row,
        ],
        'count' => 4,
        'plugin_configuration' => [],
      ],
      'Missing custom scheme as config' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(FALSE),
        ],
        'expected_data' => [],
        'count' => 0,
        'plugin_configuration' => [
          'scheme' => '_missing_custom',
        ],
      ],
      // Image: no data for alt, nor title; no image fields present, neither alt
      // nor title fields were required.
      'Image: alt or title not allowed, not required; no image field' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(FALSE),
        ],
        'expected_data' => [$expected_image_row_with_default_alt_title_conf],
        'count' => 1,
        'plugin_configuration' => [
          'type' => 'image',
          'scheme' => 'public',
        ],
      ],
      // Image: No data for alt, nor title; image field is present but it does
      // not show alt or title, neither alt nor title fields were required on
      // media.
      'Image: alt or title not allowed, not required; with image field' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(),
        ],
        'expected_data' => [$expected_image_row_with_default_alt_title_conf],
        'count' => 1,
        'conf' => [
          'type' => 'image',
          'scheme' => 'public',
        ],
      ],
      // Image: Data for alt and title; neither alt nor title fields were
      // required on media, node image field does not show alt or title.
      'Image: alt or title not allowed, not required; no field, but alt and title data present' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(TRUE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(TRUE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(FALSE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(),
        ],
        'expected_data' => [
          [
            'field_name' => 'field_media_image',
            'type' => 'image',
            'scheme' => 'public',
            'file_extensions' => 'png gif jpg jpeg webp',
            'alt_field' => TRUE,
            'title_field' => TRUE,
            'alt_field_required' => FALSE,
            'title_field_required' => FALSE,
          ],
        ],
        'count' => 1,
        'conf' => [
          'type' => 'image',
          'scheme' => 'public',
        ],
      ],
      // Image: No data for alt, nor title; neither alt nor title fields were
      // required on media, node image field present without alt or title.
      'Image: alt or title not allowed, not required; image field present; no alt or title data' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(TRUE, FALSE, FALSE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(),
        ],
        'expected_data' => [$expected_image_row_with_default_alt_title_conf],
        'count' => 1,
        'conf' => [
          'type' => 'image',
          'scheme' => 'public',
        ],
      ],
      // Image: No data for alt, nor title; neither alt nor title fields were
      // required on media, node image fields present with alt and title.
      'Image: alt and title allowed but not required; image field present, no alt and title data' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(TRUE, TRUE, TRUE, FALSE, FALSE),
          'field_config' => static::getFieldConfigTableData(),
        ],
        'expected_data' => [
          [
            'field_name' => 'field_media_image',
            'type' => 'image',
            'scheme' => 'public',
            'file_extensions' => 'png gif jpg jpeg webp',
            'alt_field' => TRUE,
            'title_field' => TRUE,
            'alt_field_required' => FALSE,
            'title_field_required' => FALSE,
          ],
        ],
        'count' => 1,
        'conf' => [
          'type' => 'image',
          'scheme' => 'public',
        ],
      ],
      // Image: No data for alt, nor title; alt is required on media, node image
      // fields present with alt and title.
      'Image: alt and title allowed, alt required; image field present, no alt and title data' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(TRUE, TRUE, TRUE, TRUE, FALSE),
          'field_config' => static::getFieldConfigTableData(),
        ],
        'expected_data' => [
          [
            'field_name' => 'field_media_image',
            'type' => 'image',
            'scheme' => 'public',
            'file_extensions' => 'png gif jpg jpeg webp',
            'alt_field' => TRUE,
            'title_field' => TRUE,
            'alt_field_required' => TRUE,
            'title_field_required' => FALSE,
          ],
        ],
        'count' => 1,
        'conf' => [
          'type' => 'image',
          'scheme' => 'public',
        ],
      ],
      // Image: No data for alt, nor title; alt and title are required on media,
      // node image fields present with alt and title allowed.
      'Image: alt and title allowed and required; image field present, no alt and title data' => [
        'source_data' => [
          'file_managed' => static::getFileManagedTableData(),
          'field_data_field_file_image_alt_text' => static::getFieldDataFieldFileImageAltTextTableData(FALSE),
          'field_data_field_file_image_title_text' => static::getFieldDataFieldFileImageTitleTextTableData(FALSE),
          'field_config_instance' => static::getFieldConfigInstanceTableData(TRUE, TRUE, TRUE, TRUE, TRUE),
          'field_config' => static::getFieldConfigTableData(),
        ],
        'expected_data' => [
          [
            'field_name' => 'field_media_image',
            'type' => 'image',
            'scheme' => 'public',
            'file_extensions' => 'png gif jpg jpeg webp',
            'alt_field' => TRUE,
            'title_field' => TRUE,
            'alt_field_required' => TRUE,
            'title_field_required' => TRUE,
          ],
        ],
        'count' => 1,
        'conf' => [
          'type' => 'image',
          'scheme' => 'public',
        ],
      ],
    ];
  }

}
